@@ -109,11 +109,11 @@ class CompressZip(CompressInterface):
 		return self.__instance.read(file)
 
 	def __iter__(self):
-		for item in self.__instance.infolist():
+		for item in self.__instance.namelist():
 			if item.endswith('/'):
 				continue
-				
-			yield item.filename
+
+			yield item
 
 
 	def close(self):
